*******************************************************************************
*For z/OS mainframe, use the following guide:
*
*//JOBCARD JOB etc.
*//HHSHCC EXEC SAS9,REGION=8M,
*// OPTIONS='ERRORS=0,NOCENTER,NEWS'
*//WORK  DD SPACE=(CYL,(1000,2))
*//WORK1 DD SPACE=(CYL,(2000,2))
*//LIBRARY DD DISP=SHR,DSN=XX.FORMATS.LIBRARY /*location of formats*/
*//IN0 DD DISP=SHR,DSN=XX.MACROS      /*location of external macros*/
*//IN1 DD DISP=SHR,DSN=XX.PERSON      /*location of person-level SAS dataset*/
*//IN2 DD DISP=SHR,DSN=XX.DIAG        /*location of diagnosis SAS dataset*/  
*//INCOEF DD DISP=SHR,DSN=XX.COEFF    /*location of coefficients SAS dataset*/
*//OUT DD DISP=(NEW,CATLG,KEEP),      /*output SAS dataset, person-level scores*/
*//    DSN=XX.PERSON.OUTPUT,              
*//    SPACE=(TRK,(200,10),RLSE)
*//SYSIN  DD *
*
*******************************************************************************
*For MS Windows, Linux, Unix, use the following guide;
*
*LIBNAME  LIBRARY "location of formats";
*FILENAME IN0     "location of external macros";  
*LIBNAME  IN1     "location of person-level SAS dataset";
*LIBNAME  IN2     "location of diagnosis SAS dataset";
*LIBNAME  INCOEF  "location of coefficients SAS dataset";
*LIBNAME  OUT     "output SAS dataset of person-level scores"; 

*******************************************************************************;
dm "out;clear;log;clear;";

options linesize=132 errors=30 center pagesize=50 msglevel=I pageno=1
 formchar="|=|-/\+>*" nodate mprint missing=".";
 
options dkricond=error dkrocond=error;

%let runday=%sysfunc(today(),date9.);
%let runtime=%sysfunc(time(),hhmm7.);
%let PROGRAM=%str(V0313L1P.SAS);
 
options compress=YES;
 
options dsoptions=nonote2err; run;
 
options obs=max;
 
title "&runday at &runtime, Pgm: &PROGRAM";
footnote;

*
 ***********************************************************************
 *  
 * Program V0313L1P creates 127 0/1 payment model HHS HCC variables 
 * and a set of score variables for each enrollee in the PERSON
 * SAS dataset (provided by the user).
 *
 * If an enrollee has at least one diagnosis in the DIAGnosis SAS dataset
 * (provided by the user) then HHS HCC variables are created, otherwise 
 * HHS HCCs are set to 0 for the enrollee.
 *
 * Score variables are created using calibration coefficients from three 
 * models (Adult, Child, Infant), each with five `metal` levels 
 * (Platinum, Gold, Silver, Bronze, Catastrophic):
 *
 *    1) Adult  Platinum        (AP)
 *    2) Adult  Gold            (AG)
 *    3) Adult  Silver          (AS)
 *    4) Adult  Bronze          (AB)
 *    5) Adult  Catastrophic    (AC)
 *    6) Child  Platinum        (CP)
 *    7) Child  Gold            (CG)
 *    8) Child  Silver          (CS)
 *    9) Child  Bronze          (CB)
 *   10) Child  Catastrophic    (CC)
 *   11) Infant Platinum        (IP)
 *   12) Infant Gold            (IG)
 *   13) Infant Silver          (IS)
 *   14) Infant Bronze          (IB)
 *   15) Infant Catastrophic    (IC).
 *
 * Both input SAS datasets, PERSON and DIAG, must be ordered by enrollee ID, i.e.,
 * the user must ensure that each dataset is sorted by the common identifier. 
 * This identifier is named in user-provided macro variable &IDVAR.
 *
 * The PERSON SAS dataset must contain the following variables and values:
 *  &IDVAR        - unique enrollee ID (e.g., Medicare HICNO), character or numeric,
 *                   any valid length
 *  AGE_FIRST     - age in first month of enrollment in benefit year, numeric, 0/1/2/...
 *  AGE_LAST      - age as of last day of enrollment in benefit year, numeric, 0/1/2/...
 *  SEX           - sex, character, M/F
 *  METAL         - enrollee`s plan level, character, P/G/S/B/C
 *  CSR_INDICATOR - cost sharing reduction indicator, numeric, 0/1/2/3/4/5/6/7/8
 *
 * The DIAG SAS dataset must contain the following variables and values:
 *  &IDVAR        - unique enrollee ID (e.g., Medicare HICNO), character or numeric,
 *                   any valid length
 *  DIAG          - ICD9 diagnosis, character
 *  If an enrollee has N diagnoses, s/he will have N records in the DIAG dataset. If an
 *  enrollee has no diagnoses, s/he will have zero records in the DIAG dataset.
 *
 * V0313L1P passes parameters to main macro V0313L1M, which calls various internal and
 * external macros. External macros are:
 *  V03EDIT1 - ICD9 edits based on age and/or sex
 *  AGESEXV5 - creates age/sex variables
 *  V03127M1 - assigns one ICD9 to multiple CCs
 *  V03127L1 - assigns labels to HHS HCCs
 *  V03127H1 - sets selected HHS HCCs to zero based on hierarchical relationships
 *  SCOREV2  - calculates score variables.
 *
 * A SAS format that maps ICD9s to CCs is required. The format is specified as
 * parameter FMNAME in the main macro call. 
 *
 * Program steps:
 *  Step 1:   include external macros. The external macros are most likely to vary
 *            among releases.
 *  Step 2:   define internal macro variables, formats, internal macros. The
 *            internal macros are least likely to vary among releases.
 *  Step 3:   merge PERSON and DIAGnosis datasets, and output one record for each
 *            enrollee record in the PERSON dataset. Output records must be fully
 *            compliant with validity rules (e.g., SEX must be M/m/F/f).
 *  Step 3.1: declare lengths, retained variables, arrays
 *  Step 3.2: append calibration coefficients
 *  Step 3.3: merge PERSON and DIAGnosis datasets by &IDVAR
 *  Step 3.4: tasks when the enrollee`s first record is detected
 *  Step 3.5: if there are any diagnoses for an enrollee:
 *            - perform ICD9 edits
 *            - create additional CCs for selected diagnoses 
 *  Step 3.6: tasks when the enrollee`s last record is detected:
 *            - create demographic variables (macro AGESEXV5)
 *            - create HCCs with hierarchy rules (macro V03127H1)
 *            - set HCCs to zero if there are no diagnoses for enrollee  
 *            - apply validity filters     
 *            - create additional model-specific variables                    
 *            - create scores     
 *            - define formats, labels.                              
 *  Step 4: contents and data dump
 *
 * User inputs:
 * The user provides two SAS datasets with the variables described above, 
 * each sorted by &IDVAR, and sets the following parameters in the macro call:
 *  INP      - SAS input PERSON SAS dataset
 *  IND      - SAS input DIAGnosis SAS dataset
 *  OUTDATA  - SAS output SAS dataset
 *  IDVAR    - name of enrollee ID variable (e.g., Medicare HICNO)
 *  KEEPVAR  - variables in output dataset in addition to &IDVAR
 *  FMNAME   - format that crosswalks ICD9s to HHS CCs
 *  AGEFMT   - format that crosswalks ICD9s to acceptable age range in
 *             case age-related edits are to be performed
 *  SEXFMT   - format that crosswalks ICD9s to acceptable sex in case
 *             sex-related edits are to be performed
 *
 * Platforms: software has been tested using SAS v9 on three platforms:
 * MS Windows (Intel PC), Linux (Intel server), z/OS (IBM mainframe).
 *
 **********************************************************************;

** housekeeping **;
proc delete data=work._all_; run;

** load and run primary macro **;
%inc IN0("V0313L1M.SAS") / source2;

** user provides parameters below **;
%V0313L1M( INP      = IN1.Person,
           IND      = IN2.Diag,
           OUTDATA  = OUT.Master,
           IDVAR    = ENROLID,
           KEEPVAR  =
                      AGE_FIRST 
                      AGE_LAST 
                      SEX 
                      METAL 
                      CSR_INDICATOR 
                      SCORE_: 
                      CSR_ADJ_SCR_:
                      /*_ALL_*/,
           FMNAME   = HHS_I03131Y11Y12Y13OC,
           AGEFMT   = HHS_AGEY11Y12Y13OMCE,
           SEXFMT   = HHS_SEXY11Y12Y13OMCE
         ); run;

** end **;
